CREATE DATABASE CRM DEFAULT CHARACTER SET utf8;

use CRM;

CREATE TABLE color (
	color VARCHAR(15),
	file VARCHAR(15) NOT NULL,
	CONSTRAINT pk_color PRIMARY KEY(color)
) ENGINE=InnoDB;


CREATE TABLE CRMUser (
	id INT AUTO_INCREMENT,
	user VARCHAR(50),
	password CHAR(40) NOT NULL,
	email VARCHAR(40) NOT NULL,
	accessLevel tinyInt NOT NULL,
	color VARCHAR(15),
	CONSTRAINT pk_CRMUser PRIMARY KEY(id),
	CONSTRAINT fk_CRMUserColor FOREIGN KEY (color) REFERENCES color (color) ON DELETE RESTRICT ON UPDATE CASCADE	
) ENGINE=InnoDB;


CREATE TABLE logUser (
	logId INT AUTO_INCREMENT,
	userId INT,
	logIn TIMESTAMP NOT NULL,
	logOut TIMESTAMP,
	CONSTRAINT pk_logUser PRIMARY KEY(logId),
	CONSTRAINT fk_logUserCRMUser FOREIGN KEY (userId) REFERENCES CRMUser (id) ON DELETE CASCADE ON UPDATE CASCADE		
) ENGINE=InnoDB;


CREATE TABLE country (
	id INT AUTO_INCREMENT,
  	ISONum smallint(6) DEFAULT NULL,
  	ISO2 char(2) DEFAULT NULL,
  	ISO3 char(3) DEFAULT NULL,
 	nameES varchar(80) DEFAULT NULL,
 	nameEN varchar(80) DEFAULT NULL,
  	CONSTRAINT pk_country PRIMARY KEY (id),
  	CONSTRAINT uk_country UNIQUE KEY (nameES)
) ENGINE=InnoDB;


CREATE TABLE businessType (
	name VARCHAR(30),
	CONSTRAINT pk_businessType PRIMARY KEY (name)
) ENGINE=InnoDB;


CREATE TABLE business (
	id INT AUTO_INCREMENT,
	activity VARCHAR(150),
	name VARCHAR (100),
	country VARCHAR(80),
	email VARCHAR(50),
	headOffice VARCHAR (150),
	phone VARCHAR (30),
	businessType VARCHAR(30),
	creationDate TIMESTAMP,
	comment VARCHAR(500),
	CONSTRAINT pk_business PRIMARY KEY (id),
	CONSTRAINT uk_business UNIQUE KEY (name),
	CONSTRAINT fk_businessCountry FOREIGN KEY (country) REFERENCES country (nameES) ON DELETE RESTRICT ON UPDATE CASCADE, 
	CONSTRAINT fk_businessBusinessType FOREIGN KEY (businessType) REFERENCES businessType (name) ON DELETE RESTRICT ON UPDATE CASCADE
) ENGINE=InnoDB;


CREATE TABLE document (
	id INT AUTO_INCREMENT,
	businessId INT,
	description VARCHAR(150),
	file MEDIUMBLOB NOT NULL,
	documentType VARCHAR(5) NOT NULL,
	fileType VARCHAR(10) NOT NULL,
	CONSTRAINT pk_document PRIMARY KEY (id),
	CONSTRAINT fk_documentBusiness FOREIGN KEY (businessId) REFERENCES business(id) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB;


CREATE TABLE contact (
	id INT AUTO_INCREMENT,
	address VARCHAR (150),
	businessId INT,
	city VARCHAR(100),
	comment VARCHAR(500),
	country VARCHAR(50),
	creationDate TIMESTAMP,
	email VARCHAR(50) NOT NULL,
	name VARCHAR(20) NOT NULL,
	phone VARCHAR (30),
	mobile VARCHAR (30),
	surname VARCHAR (50) NOT NULL,
	charge VARCHAR(50),
	linkedin VARCHAR(100),
	CONSTRAINT pk_contact PRIMARY KEY (id),
	CONSTRAINT uk_contact UNIQUE KEY (name, surname),
	CONSTRAINT fk_contactBusiness FOREIGN KEY (businessId) REFERENCES business (id) ON DELETE CASCADE ON UPDATE CASCADE,
	CONSTRAINT fk_contactCountry FOREIGN KEY (country) REFERENCES country (nameES) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB;


CREATE TABLE appointment (
	id INT AUTO_INCREMENT,
	active boolean,
	comment VARCHAR(1000),
	contactId INT,
	creationDate TIMESTAMP NOT NULL,
	remember TIMESTAMP,
	sourceType VARCHAR(20),
	summary VARCHAR(100) NOT NULL,
	userId INT,
	CONSTRAINT pk_appointment PRIMARY KEY (id),
	CONSTRAINT fk_appointmentContact FOREIGN KEY (contactId) REFERENCES contact (id) ON DELETE CASCADE ON UPDATE CASCADE,
	CONSTRAINT fk_appointmentCRMUser FOREIGN KEY (userId) REFERENCES CRMUser (id) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB;


CREATE TABLE contactListEmail (
	tmpId INT,
	country VARCHAR(50),
	email VARCHAR(50) NOT NULL,
	name VARCHAR(20) NOT NULL,
	surname VARCHAR (50) NOT NULL,
	businessName VARCHAR (100) NOT NULL, 
	CONSTRAINT pk_contact PRIMARY KEY (tmpId)
) ENGINE=InnoDB;


INSERT INTO businessType (name) VALUES
("Integrador"),
("Distribuidor"),
("Comisionista"),
("Partner"),
("Otros");


INSERT INTO color (file, color) VALUES
("tag_yellow.png", "Amarillo"),
("tag_blue.png", "Azul"),
("tag_white.png", "Blanco"),
("tag_cyan.png", "Cian"),
("tag_grey.png", "Gris"),
("tag_brown.png", "Marrón"),
("tag_black.png", "Negro"),
("tag_purpure.png", "Púrpura"),
("tag_red.png", "Rojo"),
("tag_green.png", "Verde"),
("tag_pink.png", "Rosa");

INSERT INTO CRMUser (user, password, accessLevel, color) VALUES
("root", "7110eda4d09e062aa5e4a390b0a572ac0d2c0220", 99, "Rojo");



INSERT INTO country (id, ISONum, ISO2, ISO3, nameES, nameEN) VALUES
(1, 4, 'AF', 'AFG', 'Afganistán', 'Afghanistan'),
(2, 248, 'AX', 'ALA', 'Islas Gland', 'Aland Islands'),
(3, 8, 'AL', 'ALB', 'Albania', 'Albania'),
(4, 276, 'DE', 'DEU', 'Alemania', 'Germany'),
(5, 20, 'AD', 'AND', 'Andorra', 'Andorra'),
(6, 24, 'AO', 'AGO', 'Angola', 'Angola'),
(7, 660, 'AI', 'AIA', 'Anguilla', 'Anguilla'),
(8, 10, 'AQ', 'ATA', 'Antártida', 'Antarctica'),
(9, 28, 'AG', 'ATG', 'Antigua y Barbuda', 'Antigua and Barbuda'),
(10, 530, 'AN', 'ANT', 'Antillas Holandesas', 'Netherlands Antilles'),
(11, 682, 'SA', 'SAU', 'Arabia Saudí', 'Saudi Arabia'),
(12, 12, 'DZ', 'DZA', 'Argelia', 'Algeria'),
(13, 32, 'AR', 'ARG', 'Argentina', 'Argentina'),
(14, 51, 'AM', 'ARM', 'Armenia', 'Armenia'),
(15, 533, 'AW', 'ABW', 'Aruba', 'Aruba'),
(16, 36, 'AU', 'AUS', 'Australia', 'Australia'),
(17, 40, 'AT', 'AUT', 'Austria', 'Austria'),
(18, 31, 'AZ', 'AZE', 'Azerbaiyán', 'Azerbaijan'),
(19, 44, 'BS', 'BHS', 'Bahamas', 'Bahamas'),
(20, 48, 'BH', 'BHR', 'Bahréin', 'Bahrain'),
(21, 50, 'BD', 'BGD', 'Bangladesh', 'Bangladesh'),
(22, 52, 'BB', 'BRB', 'Barbados', 'Barbados'),
(23, 112, 'BY', 'BLR', 'Bielorrusia', 'Belarus'),
(24, 56, 'BE', 'BEL', 'Bélgica', 'Belgium'),
(25, 84, 'BZ', 'BLZ', 'Belice', 'Belize'),
(26, 204, 'BJ', 'BEN', 'Benin', 'Benin'),
(27, 60, 'BM', 'BMU', 'Bermudas', 'Bermuda'),
(28, 64, 'BT', 'BTN', 'Bhután', 'Bhutan'),
(29, 68, 'BO', 'BOL', 'Bolivia', 'Bolivia'),
(30, 70, 'BA', 'BIH', 'Bosnia y Herzegovina', 'Bosnia and Herzegovina'),
(31, 72, 'BW', 'BWA', 'Botsuana', 'Botswana'),
(32, 74, 'BV', 'BVT', 'Isla Bouvet', 'Bouvet Island'),
(33, 76, 'BR', 'BRA', 'Brasil', 'Brazil'),
(34, 96, 'BN', 'BRN', 'Brunéi', 'Brunei Darussalam'),
(35, 100, 'BG', 'BGR', 'Bulgaria', 'Bulgaria'),
(36, 854, 'BF', 'BFA', 'Burkina Faso', 'Burkina Faso'),
(37, 108, 'BI', 'BDI', 'Burundi', 'Burundi'),
(38, 132, 'CV', 'CPV', 'Cabo Verde', 'Cape Verde'),
(39, 136, 'KY', 'CYM', 'Islas Caimán', 'Cayman Islands'),
(40, 116, 'KH', 'KHM', 'Camboya', 'Cambodia'),
(41, 120, 'CM', 'CMR', 'Camerún', 'Cameroon'),
(42, 124, 'CA', 'CAN', 'Canadá', 'Canada'),
(43, 140, 'CF', 'CAF', 'República Centroafricana', 'Central African Republic'),
(44, 148, 'TD', 'TCD', 'Chad', 'Chad'),
(45, 203, 'CZ', 'CZE', 'República Checa', 'Czech Republic'),
(46, 152, 'CL', 'CHL', 'Chile', 'Chile'),
(47, 156, 'CN', 'CHN', 'China', 'China'),
(48, 196, 'CY', 'CYP', 'Chipre', 'Cyprus'),
(49, 162, 'CX', 'CXR', 'Isla de Navidad', 'Christmas Island'),
(50, 336, 'VA', 'VAT', 'Ciudad del Vaticano', 'Holy See (Vatican City State)'),
(51, 166, 'CC', 'CCK', 'Islas Cocos', 'Cocos (Keeling) Islands'),
(52, 170, 'CO', 'COL', 'Colombia', 'Colombia'),
(53, 174, 'KM', 'COM', 'Comoras', 'Comoros'),
(54, 180, 'CD', 'COD', 'República Democrática del Congo', 'Congo, the Democratic Republic of the'),
(55, 178, 'CG', 'COG', 'Congo', 'Congo'),
(56, 184, 'CK', 'COK', 'Islas Cook', 'Cook Islands'),
(57, 408, 'KP', 'PRK', 'Corea del Norte', 'Korea, Democratic People''s Republic of'),
(58, 410, 'KR', 'KOR', 'Corea del Sur', 'Korea, Republic of'),
(59, 384, 'CI', 'CIV', 'Costa de Marfil', 'Cote D''Ivoire'),
(60, 188, 'CR', 'CRI', 'Costa Rica', 'Costa Rica'),
(61, 191, 'HR', 'HRV', 'Croacia', 'Croatia'),
(62, 192, 'CU', 'CUB', 'Cuba', 'Cuba'),
(63, 208, 'DK', 'DNK', 'Dinamarca', 'Denmark'),
(64, 212, 'DM', 'DMA', 'Dominica', 'Dominica'),
(65, 214, 'DO', 'DOM', 'República Dominicana', 'Dominican Republic'),
(66, 218, 'EC', 'ECU', 'Ecuador', 'Ecuador'),
(67, 818, 'EG', 'EGY', 'Egipto', 'Egypt'),
(68, 222, 'SV', 'SLV', 'El Salvador', 'El Salvador'),
(69, 784, 'AE', 'ARE', 'Emiratos Árabes Unidos', 'United Arab Emirates'),
(70, 232, 'ER', 'ERI', 'Eritrea', 'Eritrea'),
(71, 703, 'SK', 'SVK', 'Eslovaquia', 'Slovakia'),
(72, 705, 'SI', 'SVN', 'Eslovenia', 'Slovenia'),
(73, 724, 'ES', 'ESP', 'España', 'Spain'),
(74, 581, 'UM', 'UMI', 'Islas ultramarinas de Estados Unidos', 'United States Minor Outlying Islands'),
(75, 840, 'US', 'USA', 'Estados Unidos', 'United States'),
(76, 233, 'EE', 'EST', 'Estonia', 'Estonia'),
(77, 231, 'ET', 'ETH', 'Etiopía', 'Ethiopia'),
(78, 234, 'FO', 'FRO', 'Islas Feroe', 'Faroe Islands'),
(79, 608, 'PH', 'PHL', 'Filipinas', 'Philippines'),
(80, 246, 'FI', 'FIN', 'Finlandia', 'Finland'),
(81, 242, 'FJ', 'FJI', 'Fiyi', 'Fiji'),
(82, 250, 'FR', 'FRA', 'Francia', 'France'),
(83, 266, 'GA', 'GAB', 'Gabón', 'Gabon'),
(84, 270, 'GM', 'GMB', 'Gambia', 'Gambia'),
(85, 268, 'GE', 'GEO', 'Georgia', 'Georgia'),
(86, 239, 'GS', 'SGS', 'Islas Georgias del Sur y Sandwich del Sur', 'South Georgia and the South Sandwich Islands'),
(87, 288, 'GH', 'GHA', 'Ghana', 'Ghana'),
(88, 292, 'GI', 'GIB', 'Gibraltar', 'Gibraltar'),
(89, 308, 'GD', 'GRD', 'Granada', 'Grenada'),
(90, 300, 'GR', 'GRC', 'Grecia', 'Greece'),
(91, 304, 'GL', 'GRL', 'Groenlandia', 'Greenland'),
(92, 312, 'GP', 'GLP', 'Guadalupe', 'Guadeloupe'),
(93, 316, 'GU', 'GUM', 'Guam', 'Guam'),
(94, 320, 'GT', 'GTM', 'Guatemala', 'Guatemala'),
(95, 254, 'GF', 'GUF', 'Guayana Francesa', 'French Guiana'),
(96, 324, 'GN', 'GIN', 'Guinea', 'Guinea'),
(97, 226, 'GQ', 'GNQ', 'Guinea Ecuatorial', 'Equatorial Guinea'),
(98, 624, 'GW', 'GNB', 'Guinea-Bissau', 'Guinea-Bissau'),
(99, 328, 'GY', 'GUY', 'Guyana', 'Guyana'),
(100, 332, 'HT', 'HTI', 'Haití', 'Haiti'),
(101, 334, 'HM', 'HMD', 'Islas Heard y McDonald', 'Heard Island and Mcdonald Islands'),
(102, 340, 'HN', 'HND', 'Honduras', 'Honduras'),
(103, 344, 'HK', 'HKG', 'Hong Kong', 'Hong Kong'),
(104, 348, 'HU', 'HUN', 'Hungría', 'Hungary'),
(105, 356, 'IN', 'IND', 'India', 'India'),
(106, 360, 'ID', 'IDN', 'Indonesia', 'Indonesia'),
(107, 364, 'IR', 'IRN', 'Irán', 'Iran, Islamic Republic of'),
(108, 368, 'IQ', 'IRQ', 'Iraq', 'Iraq'),
(109, 372, 'IE', 'IRL', 'Irlanda', 'Ireland'),
(110, 352, 'IS', 'ISL', 'Islandia', 'Iceland'),
(111, 376, 'IL', 'ISR', 'Israel', 'Israel'),
(112, 380, 'IT', 'ITA', 'Italia', 'Italy'),
(113, 388, 'JM', 'JAM', 'Jamaica', 'Jamaica'),
(114, 392, 'JP', 'JPN', 'Japón', 'Japan'),
(115, 400, 'JO', 'JOR', 'Jordania', 'Jordan'),
(116, 398, 'KZ', 'KAZ', 'Kazajstán', 'Kazakhstan'),
(117, 404, 'KE', 'KEN', 'Kenia', 'Kenya'),
(118, 417, 'KG', 'KGZ', 'Kirguistán', 'Kyrgyzstan'),
(119, 296, 'KI', 'KIR', 'Kiribati', 'Kiribati'),
(120, 414, 'KW', 'KWT', 'Kuwait', 'Kuwait'),
(121, 418, 'LA', 'LAO', 'Laos', 'Lao People''s Democratic Republic'),
(122, 426, 'LS', 'LSO', 'Lesotho', 'Lesotho'),
(123, 428, 'LV', 'LVA', 'Letonia', 'Latvia'),
(124, 422, 'LB', 'LBN', 'Líbano', 'Lebanon'),
(125, 430, 'LR', 'LBR', 'Liberia', 'Liberia'),
(126, 434, 'LY', 'LBY', 'Libia', 'Libyan Arab Jamahiriya'),
(127, 438, 'LI', 'LIE', 'Liechtenstein', 'Liechtenstein'),
(128, 440, 'LT', 'LTU', 'Lituania', 'Lithuania'),
(129, 442, 'LU', 'LUX', 'Luxemburgo', 'Luxembourg'),
(130, 446, 'MO', 'MAC', 'Macao', 'Macao'),
(131, 807, 'MK', 'MKD', 'ARY Macedonia', 'Macedonia, the Former Yugoslav Republic of'),
(132, 450, 'MG', 'MDG', 'Madagascar', 'Madagascar'),
(133, 458, 'MY', 'MYS', 'Malasia', 'Malaysia'),
(134, 454, 'MW', 'MWI', 'Malawi', 'Malawi'),
(135, 462, 'MV', 'MDV', 'Maldivas', 'Maldives'),
(136, 466, 'ML', 'MLI', 'Malí', 'Mali'),
(137, 470, 'MT', 'MLT', 'Malta', 'Malta'),
(138, 238, 'FK', 'FLK', 'Islas Malvinas', 'Falkland Islands (Malvinas)'),
(139, 580, 'MP', 'MNP', 'Islas Marianas del Norte', 'Northern Mariana Islands'),
(140, 504, 'MA', 'MAR', 'Marruecos', 'Morocco'),
(141, 584, 'MH', 'MHL', 'Islas Marshall', 'Marshall Islands'),
(142, 474, 'MQ', 'MTQ', 'Martinica', 'Martinique'),
(143, 480, 'MU', 'MUS', 'Mauricio', 'Mauritius'),
(144, 478, 'MR', 'MRT', 'Mauritania', 'Mauritania'),
(145, 175, 'YT', 'MYT', 'Mayotte', 'Mayotte'),
(146, 484, 'MX', 'MEX', 'México', 'Mexico'),
(147, 583, 'FM', 'FSM', 'Micronesia', 'Micronesia, Federated States of'),
(148, 498, 'MD', 'MDA', 'Moldavia', 'Moldova, Republic of'),
(149, 492, 'MC', 'MCO', 'Mónaco', 'Monaco'),
(150, 496, 'MN', 'MNG', 'Mongolia', 'Mongolia'),
(151, 500, 'MS', 'MSR', 'Montserrat', 'Montserrat'),
(152, 508, 'MZ', 'MOZ', 'Mozambique', 'Mozambique'),
(153, 104, 'MM', 'MMR', 'Myanmar', 'Myanmar'),
(154, 516, 'NA', 'NAM', 'Namibia', 'Namibia'),
(155, 520, 'NR', 'NRU', 'Nauru', 'Nauru'),
(156, 524, 'NP', 'NPL', 'Nepal', 'Nepal'),
(157, 558, 'NI', 'NIC', 'Nicaragua', 'Nicaragua'),
(158, 562, 'NE', 'NER', 'Níger', 'Niger'),
(159, 566, 'NG', 'NGA', 'Nigeria', 'Nigeria'),
(160, 570, 'NU', 'NIU', 'Niue', 'Niue'),
(161, 574, 'NF', 'NFK', 'Isla Norfolk', 'Norfolk Island'),
(162, 578, 'NO', 'NOR', 'Noruega', 'Norway'),
(163, 540, 'NC', 'NCL', 'Nueva Caledonia', 'New Caledonia'),
(164, 554, 'NZ', 'NZL', 'Nueva Zelanda', 'New Zealand'),
(165, 512, 'OM', 'OMN', 'Omán', 'Oman'),
(166, 528, 'NL', 'NLD', 'Países Bajos', 'Netherlands'),
(167, 586, 'PK', 'PAK', 'Pakistán', 'Pakistan'),
(168, 585, 'PW', 'PLW', 'Palau', 'Palau'),
(169, 275, 'PS', 'PSE', 'Palestina', 'Palestinian Territory, Occupied'),
(170, 591, 'PA', 'PAN', 'Panamá', 'Panama'),
(171, 598, 'PG', 'PNG', 'Papúa Nueva Guinea', 'Papua New Guinea'),
(172, 600, 'PY', 'PRY', 'Paraguay', 'Paraguay'),
(173, 604, 'PE', 'PER', 'Perú', 'Peru'),
(174, 612, 'PN', 'PCN', 'Islas Pitcairn', 'Pitcairn'),
(175, 258, 'PF', 'PYF', 'Polinesia Francesa', 'French Polynesia'),
(176, 616, 'PL', 'POL', 'Polonia', 'Poland'),
(177, 620, 'PT', 'PRT', 'Portugal', 'Portugal'),
(178, 630, 'PR', 'PRI', 'Puerto Rico', 'Puerto Rico'),
(179, 634, 'QA', 'QAT', 'Qatar', 'Qatar'),
(180, 826, 'GB', 'GBR', 'Reino Unido', 'United Kingdom'),
(181, 638, 'RE', 'REU', 'Reunión', 'Reunion'),
(182, 646, 'RW', 'RWA', 'Ruanda', 'Rwanda'),
(183, 642, 'RO', 'ROU', 'Rumania', 'Romania'),
(184, 643, 'RU', 'RUS', 'Rusia', 'Russian Federation'),
(185, 732, 'EH', 'ESH', 'Sahara Occidental', 'Western Sahara'),
(186, 90, 'SB', 'SLB', 'Islas Salomón', 'Solomon Islands'),
(187, 882, 'WS', 'WSM', 'Samoa', 'Samoa'),
(188, 16, 'AS', 'ASM', 'Samoa Americana', 'American Samoa'),
(189, 659, 'KN', 'KNA', 'San Cristóbal y Nevis', 'Saint Kitts and Nevis'),
(190, 674, 'SM', 'SMR', 'San Marino', 'San Marino'),
(191, 666, 'PM', 'SPM', 'San Pedro y Miquelón', 'Saint Pierre and Miquelon'),
(192, 670, 'VC', 'VCT', 'San Vicente y las Granadinas', 'Saint Vincent and the Grenadines'),
(193, 654, 'SH', 'SHN', 'Santa Helena', 'Saint Helena'),
(194, 662, 'LC', 'LCA', 'Santa Lucía', 'Saint Lucia'),
(195, 678, 'ST', 'STP', 'Santo Tomé y Príncipe', 'Sao Tome and Principe'),
(196, 686, 'SN', 'SEN', 'Senegal', 'Senegal'),
(197, 688, 'RS', 'SRB', 'Serbia', 'Serbia'),
(198, 690, 'SC', 'SYC', 'Seychelles', 'Seychelles'),
(199, 694, 'SL', 'SLE', 'Sierra Leona', 'Sierra Leone'),
(200, 702, 'SG', 'SGP', 'Singapur', 'Singapore'),
(201, 760, 'SY', 'SYR', 'Siria', 'Syrian Arab Republic'),
(202, 706, 'SO', 'SOM', 'Somalia', 'Somalia'),
(203, 144, 'LK', 'LKA', 'Sri Lanka', 'Sri Lanka'),
(204, 748, 'SZ', 'SWZ', 'Suazilandia', 'Swaziland'),
(205, 710, 'ZA', 'ZAF', 'Sudáfrica', 'South Africa'),
(206, 736, 'SD', 'SDN', 'Sudán', 'Sudan'),
(207, 752, 'SE', 'SWE', 'Suecia', 'Sweden'),
(208, 756, 'CH', 'CHE', 'Suiza', 'Switzerland'),
(209, 740, 'SR', 'SUR', 'Surinam', 'Suriname'),
(210, 744, 'SJ', 'SJM', 'Svalbard y Jan Mayen', 'Svalbard and Jan Mayen'),
(211, 764, 'TH', 'THA', 'Tailandia', 'Thailand'),
(212, 158, 'TW', 'TWN', 'Taiwán', 'Taiwan, Province of China'),
(213, 834, 'TZ', 'TZA', 'Tanzania', 'Tanzania, United Republic of'),
(214, 762, 'TJ', 'TJK', 'Tayikistán', 'Tajikistan'),
(215, 86, 'IO', 'IOT', 'Territorio Británico del Océano Índico', 'British Indian Ocean Territory'),
(216, 260, 'TF', 'ATF', 'Territorios Australes Franceses', 'French Southern Territories'),
(217, 626, 'TL', 'TLS', 'Timor Oriental', 'Timor-Leste'),
(218, 768, 'TG', 'TGO', 'Togo', 'Togo'),
(219, 772, 'TK', 'TKL', 'Tokelau', 'Tokelau'),
(220, 776, 'TO', 'TON', 'Tonga', 'Tonga'),
(221, 780, 'TT', 'TTO', 'Trinidad y Tobago', 'Trinidad and Tobago'),
(222, 788, 'TN', 'TUN', 'Túnez', 'Tunisia'),
(223, 796, 'TC', 'TCA', 'Islas Turcas y Caicos', 'Turks and Caicos Islands'),
(224, 795, 'TM', 'TKM', 'Turkmenistán', 'Turkmenistan'),
(225, 792, 'TR', 'TUR', 'Turquía', 'Turkey'),
(226, 798, 'TV', 'TUV', 'Tuvalu', 'Tuvalu'),
(227, 804, 'UA', 'UKR', 'Ucrania', 'Ukraine'),
(228, 800, 'UG', 'UGA', 'Uganda', 'Uganda'),
(229, 858, 'UY', 'URY', 'Uruguay', 'Uruguay'),
(230, 860, 'UZ', 'UZB', 'Uzbekistán', 'Uzbekistan'),
(231, 548, 'VU', 'VUT', 'Vanuatu', 'Vanuatu'),
(232, 862, 'VE', 'VEN', 'Venezuela', 'Venezuela'),
(233, 704, 'VN', 'VNM', 'Vietnam', 'Viet Nam'),
(234, 92, 'VG', 'VGB', 'Islas Vírgenes Británicas', 'Virgin Islands, British'),
(235, 850, 'VI', 'VIR', 'Islas Vírgenes de los Estados Unidos', 'Virgin Islands, U.s.'),
(236, 876, 'WF', 'WLF', 'Wallis y Futuna', 'Wallis and Futuna'),
(237, 887, 'YE', 'YEM', 'Yemen', 'Yemen'),
(238, 262, 'DJ', 'DJI', 'Yibuti', 'Djibouti'),
(239, 894, 'ZM', 'ZMB', 'Zambia', 'Zambia'),
(240, 716, 'ZW', 'ZWE', 'Zimbabue', 'Zimbabwe'),
(241, 499, 'ME', 'MNE', 'Montenegro', 'Montenegro'),
(242, 728, 'SD', 'SSD', 'Sudán del Sur', 'South Sudan'),
(243, 652, 'BL', 'BLM', 'San Bartolomé', 'Saint Barthelemy'),
(245, 832, 'JE', 'JEY', 'Jersey', 'Jersey'),
(246, NULL, 'CW', 'CUW', 'Curasao', 'Curacao'),
(247, 831, 'GG', 'GGY', 'Guernsey', 'Guernsey'),
(248, 833, 'IM', 'IMN', 'Isla of Man', 'Isle of Man');